Learn R Programming

E4tools (version 0.1.1)

E4.Temp.part1.extract_raw_temp: Temperature Processing Part 1: Extract raw temperature data

Description

Extract raw temperatuer data. Inputs are: (1) List of participant numbers and (2) location where ZIP folders are stored. Outputs are: (1) one RDS file per participant with all data. A working example and vignette will be added later.

Usage

E4.Temp.part1.extract_raw_temp(participant_list, ziplocation,
  rdslocation.temp, IncludeFarenheit = TRUE)

Arguments

participant_list

list of participant numbers NOTE: This should match the names of the folders (e.g., participant 1001's data should be in a folder called "1001")

ziplocation

folder location where the participant-level subfolders are (make sure that it ends in /)

rdslocation.temp

folder location where you want the RDS outputs to go (make sure that it ends in /)

IncludeFarenheit

do you want to include a column with temperature in Farenheit also? Defaults to true. Celcius, which is recorded by the E4, will always be included.

Examples

Run this code
# NOT RUN {
E4.Temp.part1.extract_raw_temp(participant_list=c(1001:1002),
ziplocation="~/documents/study/data/",
rdslocation.temp="~/documents/study/data/TEMP/")
# }

Run the code above in your browser using DataLab