Learn R Programming

E4tools (version 0.1.1)

E4.Temp.part2.bin_temp: Temperature part 2: Make temperature bins

Description

Put temperature data in bins of X minutes length

Usage

E4.Temp.part2.bin_temp(participant_list, rdslocation.temp,
  rdslocation.binnedtemp, BinLengthMin)

Arguments

participant_list

list of participant numbers NOTE: This should match the names of the folders (e.g., participant 1001's data should be in a folder called "1001")

rdslocation.temp

folder location where raw temperature (from part 1) is saved.

rdslocation.binnedtemp

folder location where you want the RDS outputs to go (make sure that it ends in /)

BinLengthMin

folder location where you want the RDS outputs to go (make sure that it ends in /)

Examples

Run this code
# NOT RUN {
E4.extras.BinEDA(participant_list=c(1001:1004),rdslocation.binnedtemp="~/study/data/EDA/",
rdslocation.binnedtemp="~/study/data/Binned_EDA/",
BinLengthMin=2,
RejectFlag=TRUE)
# }

Run the code above in your browser using DataLab