Learn R Programming

E4tools (version 0.1.1)

E4_EDA_Process.part4.BinMatchedEDA: Bin the EDA data matched to button presses

Description

This function allows you to bin the data that has been matched to the button pressess (from step 3).

Usage

E4_EDA_Process.part4.BinMatchedEDA(participant_list,
  rdslocation.MatchedEDA, rdslocation.BinnedMatchedEDA, min.after,
  min.before, control = FALSE)

Arguments

participant_list

list of participant numbers NOTE: This should match the names of the folders (e.g., participant 1001's data should be in a folder called "1001")

rdslocation.MatchedEDA

folder location of the combined EDA file from step 3. (The file is called EDA_presses_COMBINED.RDS)

rdslocation.BinnedMatchedEDA

location of folder where you want the binned data to be stored

min.after

how many minutes after a button press do you want EDA data? Enter 0 if you do not want ANY data after (i.e., you're using only data pre-press). This should match what you entered in step 3!

min.before

how many minutes before a button press do you want EDA data? Enter 0 if you do not want ANY data before (i.e., you're using only data post-press). This should match what you entered in step 3!

control

does this dataset include control cases? This should match what you did in step 3.

Examples

Run this code
# NOT RUN {
E4_EDA_Process.part4.BinMatchedEDA(participant_list=c(1001:1002),
                                  rdslocation.MatchedEDA=paste(system.file(package="E4tools"),
                                  "/extdata/output/matched_EDA/",sep=""),
                                  rdslocation.BinnedMatchedEDA=
                                  paste(tempdir(),"/extdata/output/binned_matched_EDA/",sep=""),
                                  min.after = 20,min.before = 20,control=TRUE)
# }

Run the code above in your browser using DataLab