powered by
Put temperature data in bins of X minutes length
E4.Temp.part2.bin_temp(participant_list, rdslocation.temp, rdslocation.binnedtemp, BinLengthMin)
list of participant numbers NOTE: This should match the names of the folders (e.g., participant 1001's data should be in a folder called "1001")
folder location where raw temperature (from part 1) is saved.
folder location where you want the RDS outputs to go (make sure that it ends in /)
# NOT RUN { E4.extras.BinEDA(participant_list=c(1001:1004),rdslocation.binnedtemp="~/study/data/EDA/", rdslocation.binnedtemp="~/study/data/Binned_EDA/", BinLengthMin=2, RejectFlag=TRUE) # }
Run the code above in your browser using DataLab